@@ -38,7 +38,7 @@ typedef struct _GucharmapWindowClass GucharmapWindowClass;
 
 struct _GucharmapWindow
 {
-  GtkWindow parent;
+  GtkApplicationWindow parent;
 
   GSettings *settings;
   GucharmapCharmap *charmap;
@@ -47,10 +47,6 @@ struct _GucharmapWindow
   GtkWidget *fontsel;
   GtkWidget *text_to_copy_entry;
 
-  GtkUIManager *uimanager;
-
-  GtkActionGroup *action_group;
-
   GtkWidget *search_dialog; /* takes care of all aspects of searching */
 
   guint save_last_char_idle_id;
@@ -63,14 +59,14 @@ struct _GucharmapWindow
 
 struct _GucharmapWindowClass
 {
-  GtkWindowClass parent_class;
+  GtkApplicationWindowClass parent_class;
 };
 
 #define GUCHARMAP_ICON_NAME "accessories-character-map"
 
 GType       gucharmap_window_get_type  (void);
 
-GtkWidget * gucharmap_window_new       (void);
+GtkWidget * gucharmap_window_new       (GtkApplication *application);
 
 void        gucharmap_window_set_font  (GucharmapWindow *guw,
                                         const char *font);
